@@ -8,18 +8,17 @@ from .dirsnapshot import (
     SnapshotInfo,
     SnapshotRecord,
     create_snapshot,
-    create_snapshot_in_memory,
     is_snapshot_file,
     load_snapshot,
 )
 
 __all__ = [
     "__version__",
-    "create_snapshot_in_memory",
     "create_snapshot",
     "DirDiff",
     "DirDiffResults",
-    "DirSnapshot" "is_snapshot_file",
+    "DirSnapshot",
+    "is_snapshot_file",
     "load_snapshot",
     "SnapshotInfo",
     "SnapshotRecord",
