@@ -11,6 +11,7 @@ import dataclasses
 import datetime
 import json
 import os
+import pathlib
 import sqlite3
 from collections import namedtuple
 from dataclasses import dataclass
@@ -18,6 +19,7 @@ from os import stat as osstat
 from os import walk as oswalk
 from os.path import exists as pathexists
 from os.path import join as joinpath
+from pathlib import Path
 from typing import Any, Callable, Dict, Iterator, List, Optional, Tuple, Union
 
 from ._version import __version__
@@ -28,7 +30,6 @@ from ._version import __version__
 
 
 __all__ = [
-    "create_snapshot_in_memory",
     "create_snapshot",
     "DirDiff",
     "DirDiffResults",
@@ -48,16 +49,16 @@ SnapshotInfo = namedtuple("SnapshotInfo", ["description", "directory", "datetime
 
 def create_snapshot(
     dirpath: str,
-    snapshot_db: str,
+    snapshot_db: Optional[str],
     walk: bool = True,
     description: Optional[str] = None,
-    filter_function: Optional[Callable[[str], bool]] = None,
+    filter_function: Optional[Callable[[pathlib.Path], bool]] = None,
 ) -> "DirSnapshot":
     """Factory function to create a snapshot of a directory
 
     Args:
         dir: path to directory to snapshot
-        snapshot_db: path to database to write snapshot to
+        snapshot_db: path to database to write snapshot to or None to create database in memory
         walk: if True, walk the directory tree and add all files and directories
         description: optional description of the snapshot
         filter: optional function to filter out files and directories; should return True if the file or directory should be included in the snapshot
@@ -69,6 +70,7 @@ def create_snapshot(
         ValueError if snapshot_db already exists
     """
 
+    snapshot_db = snapshot_db or ":memory:"
     if snapshot_db != ":memory:" and pathexists(snapshot_db):
         raise ValueError(f"Snapshot database {snapshot_db} already exists")
 
@@ -77,25 +79,6 @@ def create_snapshot(
     return snapshot
 
 
-def create_snapshot_in_memory(
-    dirpath: str,
-    walk: bool = True,
-    description: Optional[str] = None,
-    filter_function: Optional[Callable[[str], bool]] = None,
-) -> "DirSnapshot":
-    """Factory function to create a snapshot of a directory in memory
-
-    Args:
-        dir: path to directory to snapshot
-        walk: if True, walk the directory tree and add all files and directories
-        description: optional description of the snapshot
-
-    Returns:
-        DirSnapshot object
-    """
-    return create_snapshot(dirpath, ":memory:", walk, description, filter_function)
-
-
 def load_snapshot(snapshot_db: str) -> "DirSnapshot":
     """Factory function to load a snapshot from a database file
 
@@ -157,7 +140,13 @@ class SnapshotRecord:
     mtime: int
     user_data: Optional[Any] = None
 
+    @property
+    def Path(self) -> pathlib.Path:
+        """pathlib.Path object for the file or directory"""
+        return Path(self.path)
+
     def asdict(self):
+        """Return a dict representation of the snapshot record"""
         return dataclasses.asdict(self)
 
 
@@ -173,7 +162,7 @@ class DirSnapshot:
         snapshot_db: str,
         walk: bool = True,
         description: Optional[str] = None,
-        filter_function: Optional[Callable[[str], bool]] = None,
+        filter_function: Optional[Callable[[pathlib.Path], bool]] = None,
     ):
         """Create a snapshot from a directory
 
@@ -376,12 +365,12 @@ class DirSnapshot:
         walk: bool,
         conn: sqlite3.Connection,
         cursor: sqlite3.Cursor,
-        filter_function: Callable[[str], bool] = None,
+        filter_function: Callable[[pathlib.Path], bool] = None,
     ):
         for current_dirpath, dirnames, filenames in oswalk(dirpath):
             for dirname in dirnames:
                 pathstr = joinpath(current_dirpath, dirname)
-                if filter_function and not filter_function(pathstr):
+                if filter_function and not filter_function(Path(pathstr)):
                     continue
                 statinfo = osstat(pathstr)
                 self._add_snapshot_db_entry(
@@ -390,7 +379,7 @@ class DirSnapshot:
 
             for filename in filenames:
                 pathstr = joinpath(current_dirpath, filename)
-                if filter_function and not filter_function(pathstr):
+                if filter_function and not filter_function(Path(pathstr)):
                     continue
                 statinfo = osstat(pathstr)
                 self._add_snapshot_db_entry(
@@ -402,6 +391,9 @@ class DirSnapshot:
 
         conn.commit()
 
+    def __len__(self):
+        return self.conn.execute("SELECT COUNT(*) FROM snapshot").fetchone()[0]
+
 
 @dataclass
 class DirDiffResults:
@@ -425,7 +417,7 @@ class DirDiff:
         snapshot_a: Union[str, DirSnapshot],
         directory_or_snapshot_b: Union[str, DirSnapshot],
         walk: bool = True,
-        filter_function: Optional[Callable[[str], bool]] = None,
+        filter_function: Optional[Callable[[pathlib.Path], bool]] = None,
     ):
         """Initialize the DirDiff instance
 
@@ -447,7 +439,7 @@ class DirDiff:
         if isinstance(directory_or_snapshot_b, DirSnapshot):
             self.snapshot_b = directory_or_snapshot_b
         elif os.path.isdir(directory_or_snapshot_b):
-            self.snapshot_b = create_snapshot_in_memory(directory_or_snapshot_b, walk)
+            self.snapshot_b = create_snapshot(directory_or_snapshot_b, None, walk)
         elif is_snapshot_file(directory_or_snapshot_b):
             self.snapshot_b = load_snapshot(directory_or_snapshot_b)
         else:
@@ -461,6 +453,7 @@ class DirDiff:
 
     def diff(
         self,
+        dirs: bool = True,
         compare_function: Optional[
             Callable[[SnapshotRecord, SnapshotRecord], bool]
         ] = None,
@@ -468,12 +461,13 @@ class DirDiff:
         """Compare the current directory or snapshot to the previous snapshot
 
         Args:
+            `dirs`: if True, includes directories in the comparison, otherwise only files are compared (if dirs==True, directories will show as modified if any file contained in the directory has been modified)
             `compare_function`: optional function to filter the results, receives a pair of SnapshotRecords and returns True if the pair are equal, otherwise False
 
         Returns:
             diff results as DirDiffResults instance
         """
-        self._diff = self._diff_snapshots(compare_function)
+        self._diff = self._diff_snapshots(dirs, compare_function)
         return self._diff
 
     def report(self, include_identical=False) -> None:
@@ -531,6 +525,7 @@ class DirDiff:
 
     def _diff_snapshots(
         self,
+        dirs: bool,
         compare_function: Optional[
             Callable[[SnapshotRecord, SnapshotRecord], bool]
         ] = None,
@@ -551,7 +546,9 @@ class DirDiff:
 
         paths_b = {}
         for row_b in self.snapshot_b.records():
-            if self.filter_function and not self.filter_function(row_b.path):
+            if self.filter_function and not self.filter_function(row_b.Path):
+                continue
+            if not dirs and row_b.is_dir:
                 continue
             paths_b[row_b.path] = 1
             if row_a := self.snapshot_a.record(row_b.path):
@@ -562,7 +559,9 @@ class DirDiff:
             else:
                 diffresults["added"].append(row_b.path)
         for row_a in self.snapshot_a.records():
-            if self.filter_function and not self.filter_function(row_a.path):
+            if self.filter_function and not self.filter_function(row_a.Path):
+                continue
+            if not dirs and row_a.is_dir:
                 continue
             if row_a.path not in paths_b:
                 diffresults["removed"].append(row_a.path)
